@@ -2,9 +2,9 @@
 
 use std::{rc::Rc, sync::Arc};
 
-use crate::{MatrixToUri, ServerName};
+use crate::{matrix_uri::UriAction, MatrixToUri, MatrixUri, ServerName};
 
-/// A Matrix user ID.
+/// A Matrix [user ID].
 ///
 /// A `UserId` is generated randomly or converted from a string slice, and can be converted back
 /// into a string as needed.
@@ -14,6 +14,8 @@ use crate::{MatrixToUri, ServerName};
 /// # use ruma_identifiers::UserId;
 /// assert_eq!(<&UserId>::try_from("@carl:example.com").unwrap(), "@carl:example.com");
 /// ```
+///
+/// [user ID]: https://spec.matrix.org/v1.2/appendices/#user-identifiers
 #[repr(transparent)]
 #[derive(PartialEq, Eq, PartialOrd, Ord, Hash)]
 pub struct UserId(str);
@@ -103,7 +105,7 @@ impl UserId {
         !localpart_is_fully_conforming(self.localpart()).unwrap()
     }
 
-    /// Create a `matrix.to` reference for this user ID.
+    /// Create a `matrix.to` URI for this user ID.
     ///
     /// # Example
     ///
@@ -112,14 +114,34 @@ impl UserId {
     ///
     /// let message = format!(
     ///     r#"Thanks for the update <a href="{link}">{display_name}</a>."#,
-    ///     link = user_id!("@jplatte:notareal.hs").matrix_to_url(),
+    ///     link = user_id!("@jplatte:notareal.hs").matrix_to_uri(),
     ///     display_name = "jplatte",
     /// );
     /// ```
-    pub fn matrix_to_url(&self) -> MatrixToUri {
+    pub fn matrix_to_uri(&self) -> MatrixToUri {
         MatrixToUri::new(self.into(), Vec::new())
     }
 
+    /// Create a `matrix:` URI for this user ID.
+    ///
+    /// If `chat` is `true`, a click on the URI should start a direct message
+    /// with the user.
+    ///
+    /// # Example
+    ///
+    /// ```
+    /// use ruma_identifiers::user_id;
+    ///
+    /// let message = format!(
+    ///     r#"Thanks for the update <a href="{link}">{display_name}</a>."#,
+    ///     link = user_id!("@jplatte:notareal.hs").matrix_uri(false),
+    ///     display_name = "jplatte",
+    /// );
+    /// ```
+    pub fn matrix_uri(&self, chat: bool) -> MatrixUri {
+        MatrixUri::new(self.into(), Vec::new(), Some(UriAction::Chat).filter(|_| chat))
+    }
+
     fn colon_idx(&self) -> usize {
         self.as_str().find(':').unwrap()
     }
